@@ -1,7 +1,7 @@
 from typing import Union, List
 from killbill.clients.base import BaseClient
 from killbill.header import Header
-from killbill.enums import Audit, BlockingStateType
+from killbill.enums import Audit, BlockingStateType, TransactionType
 
 
 class AccountClient(BaseClient):
@@ -165,6 +165,34 @@ class AccountClient(BaseClient):
 
         return self._get_uuid(response.headers.get("Location"))
 
+    def get_payment_methods(
+        self,
+        header: Header,
+        account_id: str,
+        with_plugin_info: bool = False,
+        included_deleted=False,
+        plugin_property: List[str] = None,
+        audit: Audit = Audit.NONE,
+    ):
+        """Retrieve account payment methods"""
+
+        params = {
+            "withPluginInfo": with_plugin_info,
+            "includedDeleted": included_deleted,
+            "pluginProperty": plugin_property,
+            "audit": str(audit),
+        }
+
+        response = self._get(
+            f"accounts/{account_id}/paymentMethods",
+            headers=header.dict(),
+            params=params,
+        )
+
+        self._raise_for_status(response)
+
+        return response.json()
+
     def invoices(
         self,
         header: Header,
@@ -254,3 +282,99 @@ class AccountClient(BaseClient):
         self._raise_for_status(response)
 
         return response.json()
+
+    def bundles(
+        self,
+        header: Header,
+        account_id: str,
+        external_key: str = None,
+        bundles_filter: str = None,
+        audit: Audit = Audit.NONE,
+    ):
+        """Retrieve bundles for account"""
+
+        params = {
+            "externalKey": external_key,
+            "bundlesFilter": bundles_filter,
+            "audit": str(audit),
+        }
+
+        response = self._get(
+            f"accounts/{account_id}/bundles", headers=header.dict(), params=params
+        )
+
+        self._raise_for_status(response)
+
+        return response.json()
+
+    def overdue(self, header: Header, account_id: str):
+        """Retrieve overdue state for account"""
+
+        response = self._get(
+            f"accounts/{account_id}/overdue",
+            headers=header.dict(),
+        )
+
+        self._raise_for_status(response)
+
+        return response.json()
+
+    def retrieve_by_id(
+        self,
+        header: Header,
+        account_id: str,
+        account_with_balance: bool = False,
+        account_with_balance_and_cba: bool = False,
+        audit: Audit = Audit.NONE,
+    ):
+        """Retrieve account by id"""
+
+        params = {
+            "accountWithBalance": account_with_balance,
+            "accountWithBalanceAndCBA": account_with_balance_and_cba,
+            "audit": str(audit),
+        }
+
+        response = self._get(
+            f"accounts/{account_id}",
+            params=params,
+            headers=header.dict(),
+        )
+
+        self._raise_for_status(response)
+
+        return response.json()
+
+    def payments(
+        self,
+        header: Header,
+        account_id: str,
+        transaction_type: TransactionType,
+        amount: int | float,
+        payment_method_id: str | None = None,
+        control_plugin_name: List[str] | None = None,
+        plugin_property: List[str] | None = None,
+    ):
+        """Trigger a payment (authorization, purchase or credit)"""
+
+        payload = {
+            "transactionType": str(transaction_type),
+            "amount": amount,
+        }
+
+        params = {
+            "paymentMethodId": payment_method_id,
+            "controlPluginName": control_plugin_name,
+            "pluginProperty": plugin_property,
+        }
+
+        response = self._post(
+            f"accounts/{account_id}/payments",
+            headers=header.dict(),
+            payload=payload,
+            params=params,
+        )
+
+        self._raise_for_status(response)
+
+        return response.json()
